@@ -22,8 +22,7 @@
 
 #include <grantlee/taglibraryinterface.h>
 
-class KCalendarGrantleePlugin : public QObject
-    , public Grantlee::TagLibraryInterface
+class KCalendarGrantleePlugin : public QObject, public Grantlee::TagLibraryInterface
 {
     Q_OBJECT
     Q_INTERFACES(Grantlee::TagLibraryInterface)
@@ -31,10 +30,10 @@ class KCalendarGrantleePlugin : public QObject
 
 public:
     explicit KCalendarGrantleePlugin(QObject *parent = nullptr);
-    ~KCalendarGrantleePlugin();
+    ~KCalendarGrantleePlugin() override;
 
-    QHash<QString, Grantlee::Filter *> filters(const QString  &name) Q_DECL_OVERRIDE;
-    QHash<QString, Grantlee::AbstractNodeFactory *> nodeFactories(const QString &name) Q_DECL_OVERRIDE;
+    QHash<QString, Grantlee::Filter *> filters(const QString &name) override;
+    QHash<QString, Grantlee::AbstractNodeFactory *> nodeFactories(const QString &name) override;
 };
 
 #endif // KCALENDARGRANTLEEPLUGIN_H
